@@ -39,12 +39,12 @@
 
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialog.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kiconloader.h>
 #include <kprocess.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 
 NicksOnline::NicksOnline(TQWidget* parent): ChatWindow(parent)
@@ -52,14 +52,14 @@ NicksOnline::NicksOnline(TQWidget* parent): ChatWindow(parent)
     setName(i18n("Watched Nicks Online"));
     setType(ChatWindow::NicksOnline);
 
-    m_nickListView=new KListView(this);
+    m_nickListView=new TDEListView(this);
 
     // Set to false every 8 seconds to permit a whois on watched nicks lacking information.
     // Remove when server or addressbook does this automatically.
     m_whoisRequested = true;
 
     m_nickListView->addColumn(i18n("Network/Nickname/Channel"));
-    m_kabcIconSet = KGlobal::iconLoader()->loadIconSet("kaddressbook",KIcon::Small);
+    m_tdeabcIconSet = TDEGlobal::iconLoader()->loadIconSet("kaddressbook",TDEIcon::Small);
     m_nickListView->addColumn(i18n("Additional Information"));
     m_nickListView->setFullWidth(true);
     m_nickListView->setRootIsDecorated(true);
@@ -109,20 +109,20 @@ NicksOnline::NicksOnline(TQWidget* parent): ChatWindow(parent)
         "Click to create, view, or edit the KAddressBook entry associated with the nickname "
         "selected above.");
     TQWhatsThis::add(m_editContactButton, editContactButtonWT);
-    m_editContactButton->setIconSet(m_kabcIconSet);
+    m_editContactButton->setIconSet(m_tdeabcIconSet);
     m_changeAssociationButton = new TQPushButton(i18n("&Change Association..."),
         buttonBox, "nicksonline_changeassociation_button");
     TQString changeAssociationButtonWT = i18n(
         "Click to associate the nickname selected above with an entry in KAddressBook.");
     TQWhatsThis::add(m_changeAssociationButton, changeAssociationButtonWT);
-    m_changeAssociationButton->setIconSet(m_kabcIconSet);
+    m_changeAssociationButton->setIconSet(m_tdeabcIconSet);
     m_deleteAssociationButton = new TQPushButton(i18n("&Delete Association"),
         buttonBox, "nicksonline_deleteassociation_button");
     TQString deleteAssociationButtonWT = i18n(
         "Click to remove the association between the nickname selected above and a "
         "KAddressBook entry.");
     TQWhatsThis::add(m_deleteAssociationButton, deleteAssociationButtonWT);
-    m_deleteAssociationButton->setIconSet(m_kabcIconSet);
+    m_deleteAssociationButton->setIconSet(m_tdeabcIconSet);
 
     connect(m_editContactButton, TQT_SIGNAL(clicked()),
         this, TQT_SLOT(slotEditContactButton_Clicked()));
@@ -159,7 +159,7 @@ NicksOnline::~NicksOnline()
     delete m_nickListView;
 }
 
-KListView* NicksOnline::getNickListView()
+TDEListView* NicksOnline::getNickListView()
 {
     return m_nickListView;
 }
@@ -223,7 +223,7 @@ TQListViewItem* NicksOnline::findNetworkRoot(const TQString& name)
  * @return needWhois        True if a WHOIS needs to be performed on the nick
  *                          to get additional information.
  */
-TQString NicksOnline::getNickAdditionalInfo(NickInfoPtr nickInfo, KABC::Addressee addressee,
+TQString NicksOnline::getNickAdditionalInfo(NickInfoPtr nickInfo, TDEABC::Addressee addressee,
 bool& needWhois)
 {
     TQString info;
@@ -310,7 +310,7 @@ void NicksOnline::updateServerOnlineList(Server* servr)
             // Which server did NickInfo come from?
             Server* server=nickInfo->getServer();
             // Get addressbook entry (if any) for the nick.
-            KABC::Addressee addressee = nickInfo->getAddressee();
+            TDEABC::Addressee addressee = nickInfo->getAddressee();
             // Construct additional information string for nick.
             bool needWhois = false;
             TQString nickAdditionalInfo = getNickAdditionalInfo(nickInfo, addressee, needWhois);
@@ -333,10 +333,10 @@ void NicksOnline::updateServerOnlineList(Server* servr)
             }
             // Set Kabc icon if the nick is associated with an addressbook entry.
             if (!addressee.isEmpty())
-                nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                     TQIconSet::Small, TQIconSet::Normal, TQIconSet::On));
             else
-                nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                     TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off));
 
             TQStringList channelList = server->getNickChannels(nickname);
@@ -398,17 +398,17 @@ void NicksOnline::updateServerOnlineList(Server* servr)
             if (!nickRoot) nickRoot = new NicksOnlineItem(NicksOnlineItem::NicknameItem,offlineRoot, nickname);
             nickRoot->setText(nlvcServerName, serverName);
             // Get addressbook entry for the nick.
-            KABC::Addressee addressee = servr->getOfflineNickAddressee(nickname);
+            TDEABC::Addressee addressee = servr->getOfflineNickAddressee(nickname);
             // Format additional information for the nick.
             bool needWhois = false;
             TQString nickAdditionalInfo = getNickAdditionalInfo(0, addressee, needWhois);
             nickRoot->setText(nlvcAdditionalInfo, nickAdditionalInfo);
             // Set Kabc icon if the nick is associated with an addressbook entry.
             if (!addressee.isEmpty())
-                nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                     TQIconSet::Small, TQIconSet::Normal, TQIconSet::On));
             else
-                nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                     TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off));
         }
     }
@@ -664,7 +664,7 @@ void NicksOnline::doCommand(int id)
     // Get NickInfo object corresponding to the nickname.
     NickInfoPtr nickInfo = server->getNickInfo(nickname);
     // Get addressbook entry for the nick.
-    KABC::Addressee addressee;
+    TDEABC::Addressee addressee;
 
     if(nickInfo)
     {
@@ -885,7 +885,7 @@ void NicksOnline::slotNickListView_RightButtonClicked(TQListViewItem* item, cons
             m_popupMenu->insertItem(SmallIcon("contents"), i18n("Edit C&ontact..."), ciAddressbookEdit);
             m_popupMenu->insertSeparator();
             m_popupMenu->insertItem(i18n("&Change Association..."), ciAddressbookChange);
-            m_popupMenu->insertItem(SmallIconSet("editdelete"), i18n("&Delete Association"), ciAddressbookDelete);
+            m_popupMenu->insertItem(SmallIconSet("edit-delete"), i18n("&Delete Association"), ciAddressbookDelete);
             m_popupMenu->insertSeparator();
             m_popupMenu->insertItem(i18n("&Whois"), ciWhois);
             m_popupMenu->insertItem(i18n("Open &Query"), ciOpenQuery);
@@ -935,7 +935,7 @@ void NicksOnline::refreshItem(TQListViewItem* item)
         if (server)
         {
             NickInfoPtr nickInfo = server->getNickInfo(nickname);
-            KABC::Addressee addressee;
+            TDEABC::Addressee addressee;
             if (nickInfo)
                 addressee = nickInfo->getAddressee();
             else
@@ -948,12 +948,12 @@ void NicksOnline::refreshItem(TQListViewItem* item)
                     break;
                 case nsNoAddress:
                 {
-                    item->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                    item->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                         TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off)); break;
                 }
                 case nsHasAddress:
                 {
-                    item->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+                    item->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
                         TQIconSet::Small, TQIconSet::Normal, TQIconSet::On)); break;
                 }
             }
